@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 
 """
-Copyright (c) 2006-2021 sqlmap developers (https://sqlmap.org/)
+Copyright (c) 2006-2022 sqlmap developers (https://sqlmap.org/)
 See the file 'LICENSE' for copying permission
 """
 
@@ -62,6 +62,7 @@ class HashDB(object):
         threadData = getCurrentThreadData()
         try:
             if threadData.hashDBCursor:
+                threadData.hashDBCursor.connection.commit()
                 threadData.hashDBCursor.close()
                 threadData.hashDBCursor.connection.close()
                 threadData.hashDBCursor = None
@@ -197,6 +198,10 @@ class HashDB(object):
                     threadData.inTransaction = False
                 except sqlite3.OperationalError:
                     pass
+                except sqlite3.ProgrammingError:
+                    self.cursor = None
+                    threadData.inTransaction = False
+                    return
                 else:
                     return
 
